<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/**
 * Adds a quick edit field to the product list table.
 * This function displays the product condition field when editing via the Quick Edit link and the Bulk Edit Action.
 *
 * @return void
 */
function product_condition_quick_edit_field() {
	?>
	<div class="inline-edit-group product_condition_condition_option_field">
		<label class="alignleft">
			<span class="title">
				<?php esc_html_e( 'Product Condition', 'product-condition' ); ?>
			</span>
			<span class="input-text-wrap">
				<select class="change_product_condition_option" name="product_condition_condition_option" id="product_condition_condition_option">
					<option value="no-change"><?php esc_html_e( '— No change —', 'product-condition' ); ?></option>
					<?php
					// Get product condition options.
					$options = product_condition_options();

					foreach ( $options as $key => $value ) {
						// We need to change the text on the default product condition, so list that separately.
						switch ( $key ) {
							case 'default':
								?>
								<option value="<?php echo esc_attr( $key ); ?>"><?php esc_html_e( 'Storewide Default', 'product-condition' ); ?></option>
								<?php
								break;

							default:
								?>
								<option value="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $value ); ?></option>
								<?php
								break;
						}
						?>
						<?php
					}
					?>
				</select>
			</span>
		</label>
	</div>
	<div class="inline-edit-group product_condition_custom_condition_field">
		<label class="alignleft">
			<span class="title">
				<?php esc_html_e( 'Custom Condition', 'product-condition' ); ?>
			</span>
			<span class="input-text-wrap">
				<?php $placeholder = __( 'Leave blank for no change', 'product-condition' ); ?>
				<input type="text" placeholder="<?php echo esc_attr( $placeholder ); ?>" class="text change_product_condition_custom_option" name="product_condition_custom_condition" id="product_condition_custom_condition">
			</span>
		</label>
	</div>
	<?php
}
// Required for display when viewing the Quick Edit link (i.e. single product edits).
add_action( 'woocommerce_product_quick_edit_end', 'product_condition_quick_edit_field' );
// Required for display when viewing the Bulk Action Edit (i.e. multiple product edits).
add_action( 'woocommerce_product_bulk_edit_end', 'product_condition_quick_edit_field' );

/**
 * Save the product condition from the product list table.
 * This function saves when editing via the Quick Edit link and the Bulk Edit Action.
 *
 * @return void
 */
function product_condition_quick_edit_field_save( $product ) {
	$post_id = $product->id;
	// Make sure $_REQUEST['product_condition_condition_option'] is set and that it is not set to 'no-change'.
	if ( isset( $_REQUEST['product_condition_condition_option'] ) && 'no-change' != $_REQUEST['product_condition_condition_option'] ) {
		$new_product_condition = trim( sanitize_text_field( $_REQUEST['product_condition_condition_option'] ) );
		update_post_meta( $post_id, 'product_condition_condition_option', wc_clean( $new_product_condition ) );
	}
	// Make sure $_REQUEST['product_condition_custom_condition'] is set and that it is not set to a blank string.
	if ( isset( $_REQUEST['product_condition_custom_condition'] ) && '' != $_REQUEST['product_condition_custom_condition'] ) {
		$new_product_custom_condition = trim( sanitize_text_field( $_REQUEST['product_condition_custom_condition'] ) );
		update_post_meta( $post_id, 'product_condition_custom_condition', wc_clean( $new_product_custom_condition ) );
	}
}
// Required for saving edits from the Quick Edit link (i.e. single product edits).
add_action( 'woocommerce_product_quick_edit_save', 'product_condition_quick_edit_field_save', 10, 1 );
// Required for saving edits from the Bulk Action Edit (i.e. multiple product edits).
add_action( 'woocommerce_product_bulk_edit_save', 'product_condition_quick_edit_field_save', 10, 1 );
