<?php
/**
 * Product Condition Admin Menu
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WC_Settings_Product_Condition' ) ) {
	class WC_Settings_Product_Condition {
		public function __construct() {
			add_filter( 'woocommerce_get_sections_products', array( $this, 'add_advanced_settings_section_tab' ) );
			add_action( 'woocommerce_get_settings_products', array( $this, 'get_settings' ), 10, 2 );
		}

		public function add_advanced_settings_section_tab( $section ) {
			$section['product_condition'] = __( 'Product condition', 'product-condition' );

			return $section;
		}
		/**
		 * Get all the settings for this plugin for @see woocommerce_admin_fields() function.
		 *
		 * @return array Array of settings for @see woocommerce_admin_fields() function.
		 */
		public static function get_settings( $settings, $current_section ) {
			if ( 'product_condition' === $current_section  ) {
				// Get the list of product conditions
				$product_options = product_condition_options();
				// We don't want a default product condition to be "other"
				unset( $product_options['other'] );

				$settings = array(
					'section_title'	=> array(
						'name'	=> __( 'Product condition', 'product-condition' ),
						'type'	=> 'title',
						'desc'	=> __( 'Select the default product condition. This will be used unless overridden by individual product settings.', 'product-condition' ),
						'id'	=> 'product_condition_section_title'
					),
					'condition'		=> array(
						'name'		=> __( 'Default Product Condition', 'product-condition' ),
						'type'		=> 'select',
						'desc'		=> __( 'Select the default condition.', 'product-condition' ),
						'default'	=> 'default',
						'options'	=> $product_options,
						'id'		=> 'product_condition_default_condition'
					),
					'shop_page'		=> array(
						'name'	=> __( 'Show on Shop Page?', 'product-condition' ),
						'type'	=> 'checkbox',
						'desc'	=> __( 'Check this box if you would like the product condition to be displayed on the shop page.', 'product-condition' ),
						'id'	=> 'product_condition_shop_page'
					),
					'section_end'	=> array(
						'type'		=> 'sectionend',
						'id'		=> 'product_condition_section_end'
					)
				);
			}
			return apply_filters( 'product_condition_settings_fields', $settings );
		}
	}
	$GLOBAL['wc_product_condition'] = new WC_Settings_Product_Condition();
}
