<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/**
 * Adds the human readable product condition
 * to the product meta section.
 *
 * @return string
 */
add_action( 'woocommerce_product_meta_end', 'product_condition_display_product_meta' );
function product_condition_display_product_meta() {
	global $product;
	// Retrieve the product condition for this product
	$product_condition = product_condition_return_selected_condition( $product->get_id() );
	if ( $product_condition ) {
		// Filter for the product condition label
		$label = apply_filters( 'product_condition_display_label', __( 'Product Condition: ', 'product-condition' ), $product->get_id() );
		?>
		<span class="product_condition_wrapper">
			<span class="product_condition_title"><?php echo esc_html( $label ); ?></span>
			<span class="product_condition">
				<?php
				switch ( $product_condition ) {
					case 'other':
					case 'new-other':
						// Retrieve the custom product condition if it is set in the product settings
						$custom_condition = get_post_meta( $product->get_id(), 'product_condition_custom_condition', true );
						echo esc_html( $custom_condition );
						break;

					default:
						echo esc_html( product_condition_options( $product_condition ) );
						break;
				}
				?>
			</span>
		</span>
		<?php
	}
}

/**
 * Returns the valid schema markup for the product including itemCondition.
 *
 * @return array
 */
add_filter( 'woocommerce_structured_data_product_offer', 'product_condition_schema_markup', 70, 2 );
function product_condition_schema_markup( $markup_offer, $product ) {
	// Retrieve the product condition for this product
	$product_condition = product_condition_return_selected_condition( $product->get_id() );
	// Lookup the correct OfferItemCondition schema value.
	$item_condition = product_condition_schema_OfferItemCondition( $product_condition );

	/**
	 * If $item_condition is false, a valid condition was not provided.
	 * Only add to $markup_offer if a valid condition was provided.
	 */
	if ( $item_condition ) {
		switch ( $product_condition ) {
			case 'other':
				// Retrieve the custom product condition if it is set in the product settings
				$custom_condition = get_post_meta( $product->get_id(), 'product_condition_custom_condition', true );
				if ( !( null === $custom_condition || '' === $custom_condition ) ) {
					$markup_offer['itemCondition'] = $custom_condition;
				}
				break;

			default:
				$markup_offer['itemCondition'] = $item_condition;
				break;
		}
	}

	/**
	 * Regardless of whether or not we set an itemCondition
	 * we need to return the $markup_offer array.
	 */
	return $markup_offer;
}
