<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

add_filter( 'woocommerce_product_data_tabs', 'product_condition_add_product_data_tab', 99, 1 );
add_action( 'woocommerce_product_data_panels', 'product_condition_add_product_data_fields' );
add_action( 'woocommerce_process_product_meta', 'product_condition_save_product_data_fields' );


/**
 * Add a "Product Condition" tab to the single product
 * WooCommerce options.
 *
 * @param $product_data_tabs array
 *
 * @return array
 */
function product_condition_add_product_data_tab( $product_data_tabs ) {
	$product_data_tabs['product-condition'] = array(
		'label'  => __( 'Product Condition', 'product-condition' ),
		'target' => 'product_condition_product_data',
		'class'  => 'product_condition_product_data_tab',
	);

	return $product_data_tabs;
}

/**
 * Add Product Condition options to the "Product Condition" product tab on
 * the single pages.
 *
 * Uses WooCommerce field generators.
 */
function product_condition_add_product_data_fields() {
	global $post;

	?>
	<!-- id below must match target registered in above product_condition_add_product_data_tab function -->
	<div id="product_condition_product_data" class="panel woocommerce_options_panel">
		<div class="product_condition_product_options">
			<?php
			woocommerce_wp_select( array(
				'id'			=> 'product_condition_condition_option',
				'class'			=> 'change_product_condition_option',
				'wrapper_class'	=> '',
				'label'			=> __( 'Display Product Condition', 'product-condition' ),
				'default'		=> get_option( 'product_condition_default_option' ),
				'desc_tip'		=> false,
				'options'		=> product_condition_options()
			) );

			$custom_condition = '' !== get_post_meta( $post->ID, 'product_condition_custom_condition', true ) ?
					get_post_meta( $post->ID, 'product_condition_custom_condition', true ) :
					'';
			woocommerce_wp_text_input( array(
				'id'            => 'product_condition_custom_condition',
				'wrapper_class' => '',
				'label'         => __( 'Custom Condition', 'product-condition' ),
				'value'         => $custom_condition,

			) );

			woocommerce_wp_hidden_input( array(
				'id'			=> 'product_condition_nonce',
				'value'			=> wp_create_nonce( 'product-condition-nonce' )
			));

			?>
		</div><!-- div.wqc_product_options-->
	</div><!-- div.wqc_product_data -->
	<?php
}

/**
 * Saves Product Condition options when a product is saved.
 *
 * @param $post_id int The ID of the product being saved
 */
function product_condition_save_product_data_fields( $post_id ) {
	if ( isset( $_REQUEST ) && isset( $_REQUEST['product_condition_nonce'] ) ) {
		$nonce = sanitize_text_field( $_REQUEST['product_condition_nonce'] );
		if ( !wp_verify_nonce( $nonce, 'product-condition-nonce' ) ) {
			die ( esc_html_e( 'Failed security check', 'product-condition' ) );
		} else {
			if ( isset( $_POST ) && isset( $_POST['product_condition_condition_option'] ) ) {
				$option = sanitize_text_field( $_POST['product_condition_condition_option'] );
				update_post_meta ( $post_id, 'product_condition_condition_option', $option );
			}
			if ( isset( $_POST ) && isset( $_POST['product_condition_custom_condition'] ) ) {
				$custom_condition = sanitize_text_field( $_POST['product_condition_custom_condition'] );
				update_post_meta ( $post_id, 'product_condition_custom_condition', $custom_condition );
			}
		}
	}
}
